#Estatísticas Descritivas

#Base de dados
rm(list=ls())
df=read.csv2(
              "dataset.horses.csv"
             ,h=T
             ,d=","
             ,na.strings='.'
             ,row.names=1)

str(df)
View(df)

df$Breed=factor(df$Breed)
df$Stress.Score=factor(df$Stress.Score
                       ,levels=c('0','1','2','3','4','5')
                       ,labels=c('Score 0','Score 1','Score 2','Score 3','Score 4','Score 5'))
str(df)

#Estatísticas Descritivas

summary(df)

#Funcao para erro-padrao
se=function(x,na.rm=F){
  if(na.rm)x=na.omit(x)
  sqrt(var(x)/length(x))
}

#Funcao para intervalo de confianca de 95% baseado na distribuicao t
CI_t=function(x,ci=.95)
{
  `%>%`=magrittr::`%>%`
  Margin_Error=qt(ci+(1-ci)/2,df=length(x)-1)*sd(x)/sqrt(length(x))
  df_out=data.frame(sample_size=length(x),Mean=mean(x),sd=sd(x),
                    Margin_Error=Margin_Error,
                    'CI lower limit'=(mean(x)-Margin_Error),
                    'CI Upper limit'=(mean(x)+Margin_Error))%>%
    tidyr::pivot_longer(names_to="Measurements",values_to ="values",1:6)
  return(df_out)
}

#Uma variavel

AgeInSummary=round(summarise(df,
                             Observations=n(),
                             Minimum=min(Age),
                             FirstQuartile=quantile(Age,type=5,.25),
                             Median=median(Age),
                             Mean=mean(Age),
                             SD=sd(Age),
                             SE=se(Age),
                             ThirdQuartile=quantile(Age,type=5,.75),
                             Maximum=max(Age),
                             LowerCI=CI_t(Age)[[5,2]],
                             UpperCI=CI_t(Age)[[6,2]]),dig=2);AgeInSummary

write.csv2(AgeInSummary,'AgeInSummary.csv')

#Todas as variaveis


df[c(3:7),c(-6:-9)]
df[,c('Eye.White.Showing','Eye.Fully.Closed')]

InSummary=lapply(df[,c(-8:-9)],                 
                 function(x)round(summarise(df,
                                            Observations=n(),
                                            Minimum=na.omit(min(x)),
                                            FirstQuartile=na.omit(quantile(x,type=5,.25)),
                                            Median=na.omit(median(x)),
                                            Mean=na.omit(mean(x)),
                                            SD=na.omit(sd(x)),
                                            SE=na.omit(se(x)),
                                            ThirdQuartile=na.omit(quantile(x,type=5,.75)),
                                            Maximum=na.omit(max(x)),
                                            LowerCI=na.omit(CI_t(x)[[5,2]]),
                                            UpperCI=na.omit(CI_t(x)[[6,2]]))
                                  ,dig=2));InSummary


col0=c(colnames(df[,c(-8:-9)]))
row0=c(colnames(InSummary$Age))

table1=matrix(cbind(InSummary$Age,
                    InSummary$Cortisol,
                    InSummary$HR,
                    InSummary$IRT,
                    InSummary$Ears.Forward,
                    InSummary$Eye.White.Showing,
                    InSummary$Eye.Fully.Closed),
              nrow=length(row0),ncol=length(col0),dimnames=list(row0,col0))


table2=t(table1)

table2 %>%
  kable() %>%
  kable_styling(bootstrap_options="striped",
                full_width=T,
                font_size=12)

View(table2)

write.csv2(table2,"Descriptive Statisticals.csv")

#Todas as variaveis separado por grupo

df1=group_by(df,Breed)
InSummary_Breed=lapply(df1[,c(-8:-9)],                 
                       function(x)summarise(df1,
                                            Observations=n(),
                                            Minimum=round(na.omit(min(x)),2),
                                            FirstQuartile=round(na.omit(quantile(x,type=5,.25)),2),
                                            Median=round(na.omit(median(x)),2),
                                            Mean=round(na.omit(mean(x)),2),
                                            SD=round(na.omit(sd(x)),2),
                                            SE=round(na.omit(se(x)),2),
                                            ThirdQuartile=round(na.omit(quantile(x,type=5,.75)),2),
                                            Maximum=round(na.omit(max(x)),2),
                                            LowerCI=round(na.omit(CI_t(x)[[5,2]]),2),
                                            UpperCI=round(na.omit(CI_t(x)[[6,2]])),2)
);InSummary_Breed
