#Modelo de Regressão Linear Múltiplo

#Base de dados
rm(list=ls())
df=read.csv2("dataset.horses.csv",h=T,d=",",na.strings=".",row.names = 1)
df$Breed=factor(df$Breed)
df$Stress.Score=factor(df$Stress.Score, levels=c('0','1','2','3','4','5'),labels = c('Score 0','Score 1','Score 2','Score 3','Score 4','Score 5'))
str(df)

#Correlacao 

df1=df[,c(-8:-9)]   

df1=rename(df1,'Ears Forward'=Ears.Forward) 
df1=rename(df1,'Eye White Showing'=Eye.White.Showing)
df1=rename(df1,'Eye Fully Closed'=Eye.Fully.Closed)

str(df1)

cr=Hmisc::rcorr(as.matrix(df1),type="pearson");cr
write.csv2(round(cr$r,2),'CorreTab1.csv')
write.csv2(round(cr$P,40),'CorreTab2.1.csv')

aa=as.matrix(cor(df1,method="pearson",use="complete.obs"))

mybreaks <- c(0,.2,.4,.6,.8,1)
ggcorrplot(aa,hc.order=T,type="lower",lab=T)+
  theme(axis.text=element_text(size=10),
        axis.title=element_text(size=12,face="bold"),
        legend.text=element_text(size=12),
        legend.title=element_text(face="bold",size=12),
        panel.grid.minor=element_blank(),
        panel.grid.major=element_blank(),
        legend.position='bottom') +
  scale_colour_viridis_b()+
  scale_fill_viridis_b('Pearson',alpha=.99,begin=.2,option='D',limits=c(0,1),
                       breaks=seq(0,1,.2))

# Modelagem

MLM=lm(IRT~.
       ,df)
summary(MLM)
MLM_step=step(MLM,direction="both",steps=1001,k=qchisq(p=.05,df=1,lower.tail=F))
summary(MLM_step)
lrtest(MLM,MLM_step)

FitModel2=MLM_step
shapiro.test(resid(FitModel2))
cvm.test(resid(FitModel2))
hist(resid(FitModel2))
qqnorm(resid(FitModel2))
ols_test_breusch_pagan(FitModel2)
ols_vif_tol(FitModel2)
summary(FitModel2)
summ(FitModel2)
logLik(FitModel2)
AIC(FitModel2)
BIC(FitModel2)

NLM=lm(IRT~1,df)
lrtest(NLM,FitModel2)

# Automatizando modelos 
sink()
con=file("ModeloLinearMultiplo.log");sink(con,append=T);sink(con,append=T,type="output")
source("script.R",echo=TRUE,max.deparse.length=10000000000)
options(max.print=1000000000)

lapply(df[,-4],function(x)summary(lm(IRT~x,df)))

sink()

# Variavel qualitativa binaria

table(df$Breed)

MLM2=lm(IRT~Breed
        ,df)
summary(MLM2)

# Pos-teste comparacoes multiplas
lsmeans(MLM2,pairwise~Breed,p.adjust="bonferroni")
cld(lsmeans(MLM2,~Breed,p.adjust="bonferroni"),Letters="abcdef",alpha=.05)

# Variavel qualitativa multinomial

table(df$Stress.Score)

MLM3=lm(IRT~Stress.Score
        ,df)
summary(MLM3)

# Pos-teste comparacoes multiplas
lsmeans(MLM3,pairwise~Stress.Score,p.adjust="bonferroni")
cld(lsmeans(MLM3,~Stress.Score,p.adjust="bonferroni"),Letters="abcdef",alpha=.05)

# Variavel dummy

df2=dummy_columns(df,
                     select_columns=c('Stress.Score'),
                     remove_selected_columns=F,
                     remove_first_dummy=F)

str(df2)

# Variavel qualitativa multinomial dummy

MLM4=lm(IRT~`Stress.Score_Score 0`
            +`Stress.Score_Score 1`
            +`Stress.Score_Score 2`
            +`Stress.Score_Score 3`
            +`Stress.Score_Score 4`
            +`Stress.Score_Score 5`
        ,df2)
summary(MLM4)


